==> qmmp-plugin-pack-1.5.0.tar.bz2: qmmp-plugin-pack-1.5.0/src/Input/ffap/translations/ffap_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="43"/>
        <source>FFap Plugin</source>
        <translation>FFap-liitännäinen</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="45"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="150"/>
        <source>About FFap Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="151"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Qmmp:n FFap-ääniliitännäinen</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="152"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="153"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Toteuttanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="154"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="65"/>
        <source>Samples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="66"/>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-1.5.3.tar.bz2: qmmp-plugin-pack-1.5.3/src/Input/ffap/translations/ffap_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="43"/>
        <source>FFap Plugin</source>
        <translation>FFap Plugin</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="45"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Tiedostot Monkey&apos;s Audio</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="150"/>
        <source>About FFap Audio Plugin</source>
        <translation>tietoja: FFap Audio Plugin</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="151"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Qmmp:n FFap-ääniliitännäinen</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="152"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>Tämä laajennus tarjoaa tuen Monkey&apos;s Audio (APE)</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="153"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="154"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>Perustuu deadbeef, ffmpeg ja rockbox koodiin</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="65"/>
        <source>Samples</source>
        <translation>Samplet</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="66"/>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
</context>
</TS>
